# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import pos_config
from . import pos_order
from . import crm_team
from . import pos_session
from . import sale_order
from . import res_config_settings
